=== modified file 'NEWS'
--- NEWS	2008-03-13 15:22:16 +0000
+++ NEWS	2008-03-29 02:44:43 +0000
@@ -1,5 +1,9 @@
 0.94.0  UNRELEASED
 
+ CHANGES
+
+  * Removed tortoise-bzr, which now has its own project (http://launchpad.net/tortoisebzr)
+
  UI
 
   * Made the tags associated with a revision render next to the revision
@@ -8,6 +12,11 @@
   * Made the tag list in the revision view be comma-separated. (Daniel Schierbeck)
 
   * Add bugs tab in the branch view. (Jelmer Vernooij)
+  
+  * New Tango-styled icons. This time properly licensed under the GPL.
+    (Simon Pascal Klein)
+
+  * Support showing multiple branches in "bzr viz". (Jelmer Vernooij)
 
  BUG FIXES
 
@@ -15,7 +24,7 @@
  
   * Catch UnsupportedProtocol exception in the Nautilus extension. (#77965)
   
-  * Make Nautilus extension work again. (#111826, Toshio Kuratomi)
+  * Make Nautilus extension work again. (#111826, Toshio Kuratomi, Jelmer Vernooij)
   
   * Make viz not throw errors when there are 0 commits. (#173698, Gary van der
     Merwe)
@@ -29,10 +38,14 @@
     no longer warn about newer (unknown) versions of Bazaar, on the assumption
 	the API is sufficiently stable now. (Jelmer Vernooij)
 
+  * Support child_submit_to setting in gsend. (Jelmer Vernooij)
+
  INTERNALS
 
   * Refactored the revisionview. (Daniel Schierbeck)
 
+  * It is now possible to use the diff view as a widget. (Jelmer Vernooij)
+
 0.93.0  2007-12-10
 
  UI

=== modified file '__init__.py'
--- __init__.py	2008-03-12 15:20:01 +0000
+++ __init__.py	2008-03-27 16:27:29 +0000
@@ -215,13 +215,13 @@
             wt.unlock()
 
 
-def start_viz_window(branch, revision, limit=None):
+def start_viz_window(branch, revisions, limit=None):
     """Start viz on branch with revision revision.
     
     :return: The viz window object.
     """
     from viz import BranchWindow
-    return BranchWindow(branch, revision, limit)
+    return BranchWindow(branch, revisions, limit)
 
 
 class cmd_visualise(Command):
@@ -237,21 +237,23 @@
         "revision",
         Option('limit', "Maximum number of revisions to display.",
                int, 'count')]
-    takes_args = [ "location?" ]
+    takes_args = [ "locations*" ]
     aliases = [ "visualize", "vis", "viz" ]
 
-    def run(self, location=".", revision=None, limit=None):
+    def run(self, locations_list, revision=None, limit=None):
         set_ui_factory()
-        (br, path) = branch.Branch.open_containing(location)
-        if revision is None:
-            revid = br.last_revision()
-            if revid is None:
-                return
-        else:
-            (revno, revid) = revision[0].in_history(br)
-
+        if locations_list is None:
+            locations_list = ["."]
+        revids = []
+        for location in locations_list:
+            (br, path) = branch.Branch.open_containing(location)
+            if revision is None:
+                revids.append(br.last_revision())
+            else:
+                (revno, revid) = revision[0].in_history(br)
+                revids.append(revid)
         import gtk
-        pp = start_viz_window(br, revid, limit)
+        pp = start_viz_window(br, revids, limit)
         pp.connect("destroy", lambda w: gtk.main_quit())
         pp.show()
         gtk.main()

=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-02-14 19:59:06 +0000
+++ branchview/linegraph.py	2008-03-27 16:27:29 +0000
@@ -11,7 +11,7 @@
 
 from bzrlib.tsort import merge_sort
 
-def linegraph(repository, start, maxnum, broken_line_length = None,
+def linegraph(repository, start_revs, maxnum, broken_line_length = None,
               graph_data = True, mainline_only = False):
     """Produce a directed graph of a bzr repository.
 
@@ -42,15 +42,19 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
-    graph_parents = repository.get_revision_graph(start)
+    graph = repository.get_graph()
+    graph_parents = {}
     graph_children = {}
-    for revid in graph_parents.iterkeys():
+    for (revid, parent_revids) in graph.iter_ancestry(start_revs):
+        graph_parents[revid] = parent_revids
         graph_children[revid] = []
 
+    graph_parents["top:"] = start_revs
+
     if len(graph_parents)>0:
         merge_sorted_revisions = merge_sort(
             graph_parents,
-            start,
+            "top:",
             generate_revno=True)
     else:
         merge_sorted_revisions = ()
@@ -58,6 +62,9 @@
     if mainline_only:
         merge_sorted_revisions = [elem for elem in merge_sorted_revisions \
                                   if len(elem[3])==1 ]
+
+    assert merge_sorted_revisions[0][1] == "top:"
+    merge_sorted_revisions = merge_sorted_revisions[1:]
     
     revid_index = {}
     revno_index = {}

=== modified file 'icons/commit.png'
Binary files icons/commit.png and icons/commit.png differ
=== added file 'icons/commit.svg'
--- icons/commit.svg	1970-01-01 00:00:00 +0000
+++ icons/commit.svg	2008-03-20 09:46:07 +0000
@@ -0,0 +1,417 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   inkscape:export-ydpi="90"
+   inkscape:export-xdpi="90"
+   inkscape:export-filename="/home/klepas/Desktop/commit.png"
+   sodipodi:docname="commit.svg"
+   sodipodi:docbase="/home/dobey/Projects/gnome-icon-theme/32x32/mimetypes"
+   inkscape:version="0.45+devel"
+   sodipodi:version="0.32"
+   id="svg249"
+   height="32"
+   width="32"
+   version="1.0"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs3">
+    <linearGradient
+       id="linearGradient3702">
+      <stop
+         style="stop-color:black;stop-opacity:0;"
+         offset="0"
+         id="stop3704" />
+      <stop
+         id="stop3710"
+         offset="0.5"
+         style="stop-color:black;stop-opacity:1;" />
+      <stop
+         style="stop-color:black;stop-opacity:0;"
+         offset="1"
+         id="stop3706" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient3688">
+      <stop
+         style="stop-color:black;stop-opacity:1;"
+         offset="0"
+         id="stop3690" />
+      <stop
+         style="stop-color:black;stop-opacity:0;"
+         offset="1"
+         id="stop3692" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient4790">
+      <stop
+         style="stop-color:#000000;stop-opacity:1;"
+         offset="0"
+         id="stop4792" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="1"
+         id="stop4794" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient2251">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop2253" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop2255" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient15662">
+      <stop
+         id="stop15664"
+         offset="0.0000000"
+         style="stop-color:#ffffff;stop-opacity:1.0000000;" />
+      <stop
+         id="stop15666"
+         offset="1.0000000"
+         style="stop-color:#f8f8f8;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient269">
+      <stop
+         id="stop270"
+         offset="0.0000000"
+         style="stop-color:#a3a3a3;stop-opacity:1.0000000;" />
+      <stop
+         id="stop271"
+         offset="1"
+         style="stop-color:#8a8a8a;stop-opacity:1;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient259">
+      <stop
+         id="stop260"
+         offset="0.0000000"
+         style="stop-color:#fafafa;stop-opacity:1.0000000;" />
+      <stop
+         id="stop261"
+         offset="1.0000000"
+         style="stop-color:#bbbbbb;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3688"
+       id="radialGradient1941"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.003784,0,0,1.4,27.98813,-17.4)"
+       cx="4.9929786"
+       cy="43.5"
+       fx="4.9929786"
+       fy="43.5"
+       r="2.5" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3688"
+       id="radialGradient1943"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.003784,0,0,1.4,-20.01187,-104.4)"
+       cx="4.9929786"
+       cy="43.5"
+       fx="4.9929786"
+       fy="43.5"
+       r="2.5" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3702"
+       id="linearGradient1945"
+       gradientUnits="userSpaceOnUse"
+       x1="25.058096"
+       y1="47.027729"
+       x2="25.058096"
+       y2="39.999443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2251"
+       id="linearGradient1966"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.92714e-2,-0.573924,0.587597,-1.882297e-2,2.420403,26.69984)"
+       x1="33.396004"
+       y1="36.921333"
+       x2="34.170048"
+       y2="38.070381" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient259"
+       id="radialGradient1969"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(9.897811e-2,6.749534e-3,-7.368489e-3,0.108596,16.59403,8.644111)"
+       cx="30.653816"
+       cy="14.9373"
+       fx="30.653816"
+       fy="14.9373"
+       r="86.70845" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient269"
+       id="radialGradient1971"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.221324,0,0,0.236656,13.2883,6.480565)"
+       cx="31.863327"
+       cy="2.3667307"
+       fx="31.863327"
+       fy="2.3667307"
+       r="37.751713" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4790"
+       id="radialGradient1974"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.163103,0,0,0.855889,-17.72172,-2.318907)"
+       cx="37.030354"
+       cy="12.98915"
+       fx="37.030354"
+       fy="12.98915"
+       r="4.2929163" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient15662"
+       id="radialGradient1977"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.61826,0,0,0.664962,2.818403,0.964783)"
+       cx="8.1435566"
+       cy="7.2678967"
+       fx="8.1435566"
+       fy="7.2678967"
+       r="38.158695" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient259"
+       id="radialGradient1980"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.631936,0,0,0.686693,0.21009,0.105241)"
+       cx="33.966679"
+       cy="35.736916"
+       fx="33.966679"
+       fy="35.736916"
+       r="86.70845" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient269"
+       id="radialGradient1982"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.637055,0,0,0.681177,2.416486,0.531615)"
+       cx="8.824419"
+       cy="3.7561285"
+       fx="8.824419"
+       fy="3.7561285"
+       r="37.751713" />
+  </defs>
+  <sodipodi:namedview
+     inkscape:window-y="91"
+     inkscape:window-x="217"
+     inkscape:window-height="781"
+     inkscape:window-width="1228"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     showgrid="false"
+     inkscape:current-layer="layer5"
+     inkscape:cy="13.846756"
+     inkscape:cx="-140.2343"
+     inkscape:zoom="1"
+     inkscape:pageshadow="2"
+     inkscape:pageopacity="0.0"
+     borderopacity="1"
+     bordercolor="#666"
+     pagecolor="#ffffff"
+     id="base"
+     inkscape:showpageshadow="false"
+     width="32px"
+     height="32px"
+     showborder="false"
+     showguides="true">
+    <inkscape:grid
+       type="xygrid"
+       id="grid5376" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata4">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title>Commit</dc:title>
+        <dc:subject>
+          <rdf:Bag />
+        </dc:subject>
+        <cc:license
+           rdf:resource="http://creativecommons.org/licenses/GPL/2.0/" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Simon Pascal Klein</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:source></dc:source>
+        <dc:contributor>
+          <cc:Agent>
+            <dc:title>Jakub Steiner
+Lapo Calamandrei</dc:title>
+          </cc:Agent>
+        </dc:contributor>
+        <dc:date></dc:date>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:publisher>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:identifier></dc:identifier>
+        <dc:relation></dc:relation>
+        <dc:language></dc:language>
+        <dc:coverage></dc:coverage>
+        <dc:description></dc:description>
+      </cc:Work>
+      <cc:License
+         rdf:about="http://creativecommons.org/licenses/GPL/2.0/">
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Reproduction" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Distribution" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/Notice" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/ShareAlike" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/SourceCode" />
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:groupmode="layer"
+     id="layer6"
+     inkscape:label="Shadow" />
+  <g
+     style="display:inline"
+     inkscape:groupmode="layer"
+     inkscape:label="Base"
+     id="layer1" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer5"
+     inkscape:label="Text"
+     style="display:inline">
+    <g
+       id="g3712"
+       style="opacity:0.4"
+       transform="matrix(0.701755,0,0,0.857142,-0.842106,-8.952364)">
+      <rect
+         y="40"
+         x="38"
+         height="7"
+         width="5"
+         id="rect2801"
+         style="opacity:1;fill:url(#radialGradient1941);fill-opacity:1;stroke:none;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" />
+      <rect
+         transform="scale(-1,-1)"
+         y="-47"
+         x="-10"
+         height="7"
+         width="5"
+         id="rect3696"
+         style="opacity:1;fill:url(#radialGradient1943);fill-opacity:1;stroke:none;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" />
+      <rect
+         y="40"
+         x="10"
+         height="7.0000005"
+         width="28"
+         id="rect3700"
+         style="opacity:1;fill:url(#linearGradient1945);fill-opacity:1;stroke:none;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" />
+    </g>
+    <path
+       style="color:black;fill:url(#radialGradient1980);fill-opacity:1;fill-rule:nonzero;stroke:url(#radialGradient1982);stroke-width:1.00000072;stroke-linecap:round;stroke-linejoin:round;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:block;overflow:visible"
+       d="M 5.310745,2.5103061 L 20.737197,2.5000005 C 20.737197,2.5000005 27.5,8.7946899 27.5,9.2145506 L 27.5,28.742123 C 27.5,29.161983 27.162828,29.499993 26.744008,29.499993 L 5.310745,29.499993 C 4.8919257,29.499993 4.5547534,29.161983 4.5547534,28.742123 L 4.5547534,3.2681773 C 4.5547534,2.8483168 4.8919257,2.5103061 5.310745,2.5103061 z "
+       id="rect15391"
+       sodipodi:nodetypes="ccccccccc" />
+    <path
+       style="color:black;fill:none;fill-opacity:1;fill-rule:nonzero;stroke:url(#radialGradient1977);stroke-width:1.00000012;stroke-linecap:round;stroke-linejoin:round;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:block;overflow:visible"
+       d="M 5.6671808,3.4999984 L 21.551196,3.4999984 C 21.551196,3.4999984 26.499993,8.6647089 26.499993,8.7178748 L 26.499993,28.480219 C 26.499993,28.533385 26.457547,28.576186 26.404822,28.576186 L 5.6671808,28.576186 C 5.6144565,28.576186 5.5720107,28.533385 5.5720107,28.480219 L 5.5720107,3.5959654 C 5.5720107,3.5427997 5.6144565,3.4999984 5.6671808,3.4999984 z "
+       id="rect15660"
+       sodipodi:nodetypes="ccccccccc" />
+    <path
+       inkscape:r_cy="true"
+       inkscape:r_cx="true"
+       style="opacity:0.35714285;color:black;fill:url(#radialGradient1974);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.00000024;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible"
+       d="M 27.323473,9.240968 C 26.837898,8.3432155 23.254826,6.7539594 21.389767,6.220942 C 21.502773,7.269573 21.307915,10.432965 21.307915,10.432965 C 22.682915,9.5162974 26.803003,9.1328919 27.323473,9.240968 z "
+       id="path5348"
+       sodipodi:nodetypes="cccc" />
+    <path
+       style="color:black;fill:url(#radialGradient1969);fill-opacity:1;fill-rule:nonzero;stroke:url(#radialGradient1971);stroke-width:1.00000095;stroke-linecap:butt;stroke-linejoin:round;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:block;overflow:visible"
+       d="M 27.50257,9.260921 C 27.511353,8.3144143 23.264343,2.4338801 20.673998,2.5030914 C 21.32318,2.6589282 21.841783,6.6285296 20.914603,8.509648 C 22.749322,8.509648 26.859507,8.0180959 27.50257,9.260921 z "
+       id="path2210"
+       sodipodi:nodetypes="cccc"
+       inkscape:r_cx="true"
+       inkscape:r_cy="true" />
+    <path
+       sodipodi:nodetypes="cccc"
+       id="path2247"
+       d="M 25.837661,7.4765493 C 25.409447,6.7032728 23.392805,4.5654531 22.262495,3.8551134 C 22.40297,4.6738812 22.578236,5.9696806 22.216294,7.4410802 C 22.216294,7.4410802 25.378675,7.3834583 25.837661,7.4765493 z "
+       style="color:black;fill:none;fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1966);stroke-width:1.00000107;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible"
+       inkscape:r_cx="true"
+       inkscape:r_cy="true" />
+    <g
+       id="g5363"
+       transform="translate(-4.7746738,-4.7638245)">
+      <g
+         inkscape:label="Shadow"
+         id="g5365" />
+      <g
+         id="g5367"
+         inkscape:label="Base"
+         style="display:inline" />
+      <g
+         style="display:inline"
+         inkscape:label="Text"
+         id="g5369">
+        <path
+           style="opacity:0.15;fill:none;fill-rule:evenodd;stroke:#545454;stroke-width:4;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           d="M 14.712174,25.290633 L 18.712174,29.290633 L 27.712174,19.290633"
+           id="path5547"
+           sodipodi:nodetypes="ccc" />
+        <g
+           transform="translate(8.2121737,15.237016)"
+           id="g3287">
+          <path
+             style="fill:none;fill-rule:evenodd;stroke:#4e9a06;stroke-width:4;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             d="M 6.5,8.5 L 10.5,12.5 L 19.5,2.5"
+             id="path3285"
+             sodipodi:nodetypes="ccc" />
+          <path
+             style="fill:none;fill-rule:evenodd;stroke:#8ae234;stroke-width:2;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             d="M 6.5,8.5 L 10.5,12.5 L 19.5,2.5"
+             id="path3279"
+             sodipodi:nodetypes="ccc" />
+        </g>
+        <path
+           id="path3291"
+           d="M 27.555924,16.737016 C 27.323666,16.778005 27.113367,16.899757 26.962174,17.080766 L 18.680924,26.268266 L 15.430924,23.018266 C 15.033969,22.621311 14.390379,22.621311 13.993424,23.018266 C 13.657764,23.353926 13.636424,23.846895 13.868424,24.237016 C 13.910789,24.165776 13.93213,24.07956 13.993424,24.018266 C 14.390379,23.621311 15.033969,23.621311 15.430924,24.018266 L 18.680924,27.268266 L 26.962174,18.080766 C 27.113367,17.899757 27.323666,17.778005 27.555924,17.737016 C 27.966854,17.668971 28.378956,17.847056 28.587174,18.205766 C 28.745299,17.91233 28.752221,17.538654 28.587174,17.237016 C 28.383157,16.864157 27.97524,16.667582 27.555924,16.737016 z"
+           style="opacity:0.55598456;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" />
+      </g>
+    </g>
+  </g>
+</svg>

=== modified file 'icons/commit16.png'
Binary files icons/commit16.png and icons/commit16.png differ
=== added file 'icons/commit16.svg'
--- icons/commit16.svg	1970-01-01 00:00:00 +0000
+++ icons/commit16.svg	2008-03-20 09:46:07 +0000
@@ -0,0 +1,173 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   inkscape:export-ydpi="90"
+   inkscape:export-xdpi="90"
+   inkscape:export-filename="/home/klepas/Desktop/commit16.png"
+   sodipodi:docname="commit16.svg"
+   sodipodi:docbase="/home/dobey/Projects/gnome-icon-theme/32x32/mimetypes"
+   inkscape:version="0.45+devel"
+   sodipodi:version="0.32"
+   id="svg249"
+   height="16"
+   width="16"
+   version="1.0"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs3">
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       id="perspective19"
+       inkscape:vp_x="-50 : 600 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="700 : 600 : 1"
+       inkscape:persp3d-origin="300 : 400 : 1" />
+  </defs>
+  <sodipodi:namedview
+     inkscape:window-y="91"
+     inkscape:window-x="217"
+     inkscape:window-height="781"
+     inkscape:window-width="1228"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     showgrid="false"
+     inkscape:current-layer="layer5"
+     inkscape:cy="7.4176588"
+     inkscape:cx="8.7400151"
+     inkscape:zoom="1"
+     inkscape:pageshadow="2"
+     inkscape:pageopacity="0.0"
+     borderopacity="0.11764706"
+     bordercolor="#666666"
+     pagecolor="#ffffff"
+     id="base"
+     inkscape:showpageshadow="false"
+     width="32px"
+     height="32px"
+     showborder="true"
+     showguides="true">
+    <inkscape:grid
+       type="xygrid"
+       id="grid5376" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata4">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title>Commit</dc:title>
+        <dc:subject>
+          <rdf:Bag />
+        </dc:subject>
+        <cc:license
+           rdf:resource="http://creativecommons.org/licenses/GPL/2.0/" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Simon Pascal Klein</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:source></dc:source>
+        <dc:contributor>
+          <cc:Agent>
+            <dc:title>Lapo Calamandrei</dc:title>
+          </cc:Agent>
+        </dc:contributor>
+        <dc:date></dc:date>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:publisher>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:identifier></dc:identifier>
+        <dc:relation></dc:relation>
+        <dc:language></dc:language>
+        <dc:coverage></dc:coverage>
+        <dc:description></dc:description>
+      </cc:Work>
+      <cc:License
+         rdf:about="http://creativecommons.org/licenses/GPL/2.0/">
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Reproduction" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Distribution" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/Notice" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/ShareAlike" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/SourceCode" />
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:groupmode="layer"
+     id="layer6"
+     inkscape:label="Shadow" />
+  <g
+     style="display:inline"
+     inkscape:groupmode="layer"
+     inkscape:label="Base"
+     id="layer1" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer5"
+     inkscape:label="Text"
+     style="display:inline">
+    <g
+       id="g5363"
+       transform="matrix(0.9275362,0,0,0.9275362,-11.646074,-13.668122)">
+      <g
+         inkscape:label="Shadow"
+         id="g5365" />
+      <g
+         id="g5367"
+         inkscape:label="Base"
+         style="display:inline" />
+      <g
+         style="display:inline"
+         inkscape:label="Text"
+         id="g5369">
+        <path
+           style="opacity:0.15;fill:none;fill-rule:evenodd;stroke:#545454;stroke-width:4.3125;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           d="M 14.712174,25.290633 L 18.712174,29.290633 L 27.712174,19.290633"
+           id="path5547"
+           sodipodi:nodetypes="ccc" />
+        <g
+           transform="translate(8.2121737,15.237016)"
+           id="g3287">
+          <path
+             style="fill:none;fill-rule:evenodd;stroke:#4e9a06;stroke-width:4.3125;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             d="M 6.5,8.5 L 10.5,12.5 L 19.5,2.5"
+             id="path3285"
+             sodipodi:nodetypes="ccc" />
+          <path
+             style="fill:none;fill-rule:evenodd;stroke:#8ae234;stroke-width:2.15625;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             d="M 6.5,8.5 L 10.5,12.5 L 19.5,2.5"
+             id="path3279"
+             sodipodi:nodetypes="ccc" />
+        </g>
+        <path
+           id="path3291"
+           d="M 27.555924,16.737016 C 27.323666,16.778005 27.113367,16.899757 26.962174,17.080766 L 18.680924,26.268266 L 15.430924,23.018266 C 15.033969,22.621311 14.390379,22.621311 13.993424,23.018266 C 13.657764,23.353926 13.636424,23.846895 13.868424,24.237016 C 13.910789,24.165776 13.93213,24.07956 13.993424,24.018266 C 14.390379,23.621311 15.033969,23.621311 15.430924,24.018266 L 18.680924,27.268266 L 26.962174,18.080766 C 27.113367,17.899757 27.323666,17.778005 27.555924,17.737016 C 27.966854,17.668971 28.378956,17.847056 28.587174,18.205766 C 28.745299,17.91233 28.752221,17.538654 28.587174,17.237016 C 28.383157,16.864157 27.97524,16.667582 27.555924,16.737016 z"
+           style="opacity:0.55598456;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1" />
+      </g>
+    </g>
+  </g>
+</svg>

=== modified file 'icons/diff.png'
Binary files icons/diff.png and icons/diff.png differ
=== modified file 'icons/diff16.png'
Binary files icons/diff16.png and icons/diff16.png differ
=== added file 'icons/diff16.svg'
--- icons/diff16.svg	1970-01-01 00:00:00 +0000
+++ icons/diff16.svg	2008-03-20 09:46:07 +0000
@@ -0,0 +1,220 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   inkscape:export-ydpi="90"
+   inkscape:export-xdpi="90"
+   inkscape:export-filename="/home/klepas/Desktop/diff16.png"
+   sodipodi:docname="diff.svg"
+   sodipodi:docbase="/home/dobey/Projects/gnome-icon-theme/32x32/mimetypes"
+   inkscape:version="0.45+devel"
+   sodipodi:version="0.32"
+   id="svg249"
+   height="16"
+   width="16"
+   version="1.0"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs3" />
+  <sodipodi:namedview
+     inkscape:window-y="127"
+     inkscape:window-x="328"
+     inkscape:window-height="781"
+     inkscape:window-width="1228"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     showgrid="false"
+     inkscape:current-layer="layer5"
+     inkscape:cy="2.7149813"
+     inkscape:cx="12.306264"
+     inkscape:zoom="1"
+     inkscape:pageshadow="2"
+     inkscape:pageopacity="0.0"
+     borderopacity="0.11764706"
+     bordercolor="#666666"
+     pagecolor="#ffffff"
+     id="base"
+     inkscape:showpageshadow="false"
+     width="32px"
+     height="32px"
+     showborder="true"
+     showguides="true">
+    <inkscape:grid
+       type="xygrid"
+       id="grid5376" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata4">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title>diff</dc:title>
+        <dc:subject>
+          <rdf:Bag />
+        </dc:subject>
+        <cc:license
+           rdf:resource="http://creativecommons.org/licenses/GPL/2.0/" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Simon Pascal Klein</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:source></dc:source>
+        <dc:contributor>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:contributor>
+        <dc:date></dc:date>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:publisher>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:identifier></dc:identifier>
+        <dc:relation></dc:relation>
+        <dc:language></dc:language>
+        <dc:coverage></dc:coverage>
+        <dc:description></dc:description>
+      </cc:Work>
+      <cc:License
+         rdf:about="http://creativecommons.org/licenses/GPL/2.0/">
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Reproduction" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Distribution" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/Notice" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/ShareAlike" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/SourceCode" />
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:groupmode="layer"
+     id="layer6"
+     inkscape:label="Shadow" />
+  <g
+     style="display:inline"
+     inkscape:groupmode="layer"
+     inkscape:label="Base"
+     id="layer1" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer5"
+     inkscape:label="Text"
+     style="display:inline">
+    <rect
+       ry="0.49718446"
+       rx="0.49718446"
+       y="0.49999952"
+       x="1.5"
+       height="6.0000005"
+       width="13"
+       id="rect6016"
+       style="opacity:1;fill:#98b9dc;fill-opacity:1;fill-rule:nonzero;stroke:#204a87;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" />
+    <rect
+       style="opacity:0;fill:#eeeeec;fill-opacity:1;stroke:none;stroke-width:1;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;display:none"
+       id="rect4038"
+       width="200"
+       height="72"
+       x="-67.882248"
+       y="51.216774"
+       inkscape:export-filename="/home/lapo/Desktop/order-stuff.png"
+       inkscape:export-xdpi="90"
+       inkscape:export-ydpi="90" />
+    <rect
+       inkscape:export-ydpi="90"
+       inkscape:export-xdpi="90"
+       inkscape:export-filename="/home/lapo/Desktop/order-stuff.png"
+       y="41.148125"
+       x="-18.94228"
+       height="72"
+       width="200"
+       id="rect5852"
+       style="opacity:0;fill:#eeeeec;fill-opacity:1;stroke:none;stroke-width:1;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;display:none" />
+    <rect
+       style="opacity:1;fill:#729fcf;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:2;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1"
+       id="rect5244"
+       width="10"
+       height="3"
+       x="3"
+       y="2"
+       rx="0"
+       ry="0" />
+    <rect
+       ry="0.5"
+       rx="0.5"
+       y="2.9999962"
+       x="7"
+       height="1"
+       width="5"
+       id="rect5238"
+       style="opacity:1;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1.00199997;stroke-linecap:square;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:1.20000057;stroke-opacity:1" />
+    <rect
+       style="opacity:1;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1.00199997;stroke-linecap:square;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:1.20000057;stroke-opacity:1"
+       id="rect5240"
+       width="2"
+       height="1"
+       x="4"
+       y="2.9999962"
+       rx="0.5"
+       ry="0.5" />
+    <rect
+       style="opacity:1;fill:#ff9a9a;fill-opacity:1;fill-rule:nonzero;stroke:#a40000;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1"
+       id="rect6018"
+       width="13"
+       height="6.0000005"
+       x="1.5"
+       y="9.5"
+       rx="0.49718446"
+       ry="0.49718446" />
+    <rect
+       ry="0"
+       rx="0"
+       y="11"
+       x="3"
+       height="3"
+       width="10"
+       id="rect6020"
+       style="opacity:1;fill:#ef2929;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:2;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" />
+    <rect
+       style="opacity:1;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1.00199997;stroke-linecap:square;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:1.20000057;stroke-opacity:1"
+       id="rect6022"
+       width="5"
+       height="1"
+       x="-9"
+       y="11.999996"
+       rx="0.5"
+       ry="0.5"
+       transform="scale(-1,1)" />
+    <rect
+       ry="0.5"
+       rx="0.5"
+       y="11.999996"
+       x="-12"
+       height="1"
+       width="2"
+       id="rect6024"
+       style="opacity:1;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1.00199997;stroke-linecap:square;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:1.20000057;stroke-opacity:1"
+       transform="scale(-1,1)" />
+  </g>
+</svg>

=== modified file 'icons/log.png'
Binary files icons/log.png and icons/log.png differ
=== modified file 'icons/log16.png'
Binary files icons/log16.png and icons/log16.png differ
=== modified file 'icons/pull.png'
Binary files icons/pull.png and icons/pull.png differ
=== modified file 'icons/pull16.png'
Binary files icons/pull16.png and icons/pull16.png differ
=== modified file 'icons/push.png'
Binary files icons/push.png and icons/push.png differ
=== modified file 'icons/push16.png'
Binary files icons/push16.png and icons/push16.png differ
=== modified file 'icons/refresh.png'
Binary files icons/refresh.png and icons/refresh.png differ
=== removed file 'tortoise-bzr.py'
--- tortoise-bzr.py	2007-03-09 16:54:51 +0000
+++ tortoise-bzr.py	1970-01-01 00:00:00 +0000
@@ -1,106 +0,0 @@
-# Simple TortoiseSVN-like Bazaar plugin for the Windows Shell
-# Published under the GNU GPL, v2 or later.
-# Copyright (C) 2007 Jelmer Vernooij <jelmer@samba.org>
-
-import pythoncom
-from win32com.shell import shell, shellcon
-import win32gui
-import win32con
-
-"""Windows shell extension that adds context menu items to Bazaar branches."""
-class BazaarShellExtension:
-    _reg_progid_ = "Bazaar.ShellExtension.ContextMenu"
-    _reg_desc_ = "Bazaar Shell Extension"
-    _reg_clsid_ = "{EEE9936B-73ED-4D45-80C9-AF918354F885}"
-    _com_interfaces_ = [shell.IID_IShellExtInit, shell.IID_IContextMenu]
-    _public_methods_ = [
-    	"Initialize", # From IShellExtInit
-	"QueryContextMenu", "InvokeCommand", "GetCommandString" # IContextMenu
-	]
-
-    def Initialize(self, folder, dataobj, hkey):
-        self.dataobj = dataobj
-
-    def QueryContextMenu(self, hMenu, indexMenu, idCmdFirst, idCmdLast, uFlags):
-        format_etc = win32con.CF_HDROP, None, 1, -1, pythoncom.TYMED_HGLOBAL
-        sm = self.dataobj.GetData(format_etc)
-        num_files = shell.DragQueryFile(sm.data_handle, -1)
-        if num_files>1:
-            msg = "&Hello from Python (with %d files selected)" % num_files
-        else:
-            fname = shell.DragQueryFile(sm.data_handle, 0)
-            msg = "&Hello from Python (with '%s' selected)" % fname
-        idCmd = idCmdFirst
-        items = []
-        if (uFlags & 0x000F) == shellcon.CMF_NORMAL: # Check == here, since CMF_NORMAL=0
-            print "CMF_NORMAL..."
-            items.append(msg)
-        elif uFlags & shellcon.CMF_VERBSONLY:
-            print "CMF_VERBSONLY..."
-            items.append(msg + " - shortcut")
-        elif uFlags & shellcon.CMF_EXPLORE:
-            print "CMF_EXPLORE..."
-            items.append(msg + " - normal file, right-click in Explorer")
-        elif uFlags & CMF_DEFAULTONLY:
-            print "CMF_DEFAULTONLY...\r\n"
-        else:
-            print "** unknown flags", uFlags
-        win32gui.InsertMenu(hMenu, indexMenu,
-                            win32con.MF_SEPARATOR|win32con.MF_BYPOSITION,
-                            0, None)
-        indexMenu += 1
-        for item in items:
-            win32gui.InsertMenu(hMenu, indexMenu,
-                                win32con.MF_STRING|win32con.MF_BYPOSITION,
-                                idCmd, item)
-            indexMenu += 1
-            idCmd += 1
-
-        win32gui.InsertMenu(hMenu, indexMenu,
-                            win32con.MF_SEPARATOR|win32con.MF_BYPOSITION,
-                            0, None)
-        indexMenu += 1
-        return idCmd-idCmdFirst # Must return number of menu items we added.
-
-    def InvokeCommand(self, ci):
-        mask, hwnd, verb, params, dir, nShow, hotkey, hicon = ci
-	# FIXME: Run the actual command
-
-    def GetCommandString(self, cmd, typ):
-        return "Hello from Python!!"
-
-registryKeys = [
-	"*\\shellex\\ContextMenuHandlers", 
-	"Directory\\Background\\shellex\\ContextMenuHandlers", 
-	"Directory\\shellex\\ContextMenuHandlers", 
-	"Folder\\shellex\\ContextmenuHandlers"
-	]
-
-def DllRegisterServer():
-    import _winreg
-    for keyname in registryKeys: 
-	    key = _winreg.CreateKey(_winreg.HKEY_CLASSES_ROOT, keyname)
-	    subkey = _winreg.CreateKey(key, "TortoiseBzr")
-	    _winreg.SetValueEx(subkey, None, 0, _winreg.REG_SZ, BazaarShellExtension._reg_clsid_)
-	    _winreg.CloseKey(subkey)
-	    _winreg.CloseKey(key)
-
-    print BazaarShellExtension._reg_desc_, "registration complete."
-
-def DllUnregisterServer():
-    import _winreg
-    try:
-	for keyname in registryKeys:
-	    _winreg.DeleteKey(_winreg.HKEY_CLASSES_ROOT,
-                                "%s\\TortoiseBzr" % keyname)
-    except WindowsError, details:
-        import errno
-        if details.errno != errno.ENOENT:
-            raise
-    print BazaarShellExtension._reg_desc_, "unregistration complete."
-
-if __name__ == '__main__':
-    from win32com.server import register
-    register.UseCommandLine(BazaarShellExtension,
-                   finalize_register = DllRegisterServer,
-                   finalize_unregister = DllUnregisterServer)

=== modified file 'ui.py'
--- ui.py	2007-07-15 15:22:29 +0000
+++ ui.py	2008-03-20 16:06:23 +0000
@@ -58,7 +58,8 @@
     def update(self, msg=None, current=None, total=None):
         if msg is not None:
             self.set_text(msg)
-        self.set_fraction(1.0 * current / total)
+        if None not in (current, total):
+            self.set_fraction(1.0 * current / total)
         while gtk.events_pending():
             gtk.main_iteration()
 

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2008-03-13 15:12:43 +0000
+++ viz/branchwin.py	2008-03-28 19:12:27 +0000
@@ -28,11 +28,11 @@
     for a particular branch.
     """
 
-    def __init__(self, branch, start, maxnum, parent=None):
+    def __init__(self, branch, start_revs, maxnum, parent=None):
         """Create a new BranchWindow.
 
         :param branch: Branch object for branch to show.
-        :param start: Revision id of top revision.
+        :param start_revs: Revision ids of top revisions.
         :param maxnum: Maximum number of revisions to display, 
                        None for no limit.
         """
@@ -41,7 +41,7 @@
         self.set_border_width(0)
 
         self.branch      = branch
-        self.start       = start
+        self.start_revs  = start_revs
         self.maxnum      = maxnum
         self.config      = GlobalConfig()
 
@@ -155,8 +155,16 @@
         view_menu.add(view_menu_compact)
         view_menu.add(gtk.SeparatorMenuItem())
 
-        for (label, name) in [("Revision _Number", "revno"), ("_Date", "date")]:
-            col = gtk.CheckMenuItem("Show " + label + " Column")
+        self.mnu_show_revno_column = gtk.CheckMenuItem("Show Revision _Number Column")
+        self.mnu_show_date_column = gtk.CheckMenuItem("Show _Date Column")
+
+        # Revision numbers are pointless if there are multiple branches
+        if len(self.start_revs) > 1:
+            self.mnu_show_revno_column.set_sensitive(False)
+            self.treeview.set_property('revno-column-visible', False)
+
+        for (col, name) in [(self.mnu_show_revno_column, "revno"), 
+                            (self.mnu_show_date_column, "date")]:
             col.set_active(self.treeview.get_property(name + "-column-visible"))
             col.connect('toggled', self._col_visibility_changed, name)
             view_menu.add(col)
@@ -222,7 +230,7 @@
         """Construct the top-half of the window."""
         # FIXME: Make broken_line_length configurable
 
-        self.treeview = TreeView(self.branch, self.start, self.maxnum, self.compact_view)
+        self.treeview = TreeView(self.branch, self.start_revs, self.maxnum, self.compact_view)
 
         self.treeview.connect('revision-selected',
                 self._treeselection_changed_cb)
@@ -236,6 +244,7 @@
             if option is not None:
                 self.treeview.set_property(col + '-column-visible', option == 'True')
 
+        self.treeview.set_property(col + '-column-visible', False)
         self.treeview.show()
 
         align = gtk.Alignment(0.0, 0.0, 1.0, 1.0)

